@@ -124,15 +124,33 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
 {
     // KDE debug categories area
     const QString confAreasFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, QStringLiteral("kde.categories"));
-    KDebugSettingsUtil::readLoggingCategories(confAreasFile, mCategories, false);
+    KDebugSettingsUtil::readLoggingCategories(confAreasFile, mCategoriesList, false);
+
+    mRenameCategoriesList.clear();
+    // Load *.renamecategories file in QStandardPaths::ConfigLocation for kde apps.
+    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
+    Q_FOREACH (const QString &dir, dirs) {
+        const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.renamecategories"));
+        Q_FOREACH (const QString &file, fileNames) {
+            mRenameCategoriesList.append(KDebugSettingsUtil::readRenameCategories(dir + file));
+        }
+    }
+    //TODO add load rename file from external kde apps.
+    dirs = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("qdebug.categories/"), QStandardPaths::LocateDirectory);
+    Q_FOREACH (const QString &dir, dirs) {
+        const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.renamecategories"));
+        Q_FOREACH (const QString &file, fileNames) {
+            mRenameCategoriesList.append(KDebugSettingsUtil::readRenameCategories(dir + file));
+        }
+    }
 
     // Load *.categories file in QStandardPaths::ConfigLocation for kde apps.
-    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
+    dirs = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
     Q_FOREACH (const QString &dir, dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.categories"));
         Q_FOREACH (const QString &file, fileNames) {
             if (file != QStringLiteral("kde.categories")) {
-                KDebugSettingsUtil::readLoggingCategories(dir + file, mCategories, true);
+                KDebugSettingsUtil::readLoggingCategories(dir + file, mCategoriesList, true);
             }
         }
     }
@@ -142,9 +160,11 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
     Q_FOREACH (const QString &dir, dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.categories"));
         Q_FOREACH (const QString &file, fileNames) {
-            KDebugSettingsUtil::readLoggingCategories(dir + QLatin1Char('/') + file, mCategories, true);
+            KDebugSettingsUtil::readLoggingCategories(dir + QLatin1Char('/') + file, mCategoriesList, true);
         }
     }
+
+
     const QByteArray rulesFilePath = qgetenv("QT_LOGGING_CONF");
     if (!rulesFilePath.isEmpty()) {
         const QList<KDebugSettingsUtil::LoadLoggingCategory> envCategories = KDebugSettingsUtil::readLoggingQtCategories(QString::fromLatin1(rulesFilePath));
@@ -158,7 +178,8 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
     // qt logging.ini
     LoadCategoriesJob job;
     job.setFileName(path);
-    job.setCategories(mCategories);
+    job.setCategories(mCategoriesList);
+    job.setRenamedCategories(mRenameCategoriesList);
     job.start();
 
     const LoggingCategory::List customCategories = job.customCategories();
@@ -221,7 +242,7 @@ void KDebugSettingsDialog::slotInsertCategories()
 {
     const QString path = QFileDialog::getOpenFileName(this, i18n("Insert Categories"));
     if (!path.isEmpty()) {
-        const KdeLoggingCategory::List insertCategoriesList = KDebugSettingsUtil::readLoggingCategoriesForInserting(path, mCategories);
+        const KdeLoggingCategory::List insertCategoriesList = KDebugSettingsUtil::readLoggingCategoriesForInserting(path, mCategoriesList);
         LoggingCategory::List newCategories;
         Q_FOREACH (const KdeLoggingCategory &cat, insertCategoriesList) {
             LoggingCategory loggingCat;
@@ -245,7 +266,7 @@ void KDebugSettingsDialog::slotSaveAs()
 
 void KDebugSettingsDialog::slotLoad()
 {
-    const QString path = QFileDialog::getOpenFileName(this, i18n("Load"));
+    const QString path = QFileDialog::getOpenFileName(this, i18n("Load Debug Settings Files"));
     if (!path.isEmpty()) {
         readCategoriesFiles(path);
     }
